@@ -13,7 +13,7 @@ use File::Spec;
 use Config;
 use System::Command;
 
-our $VERSION = '1.12';
+our $VERSION = '1.13';
 our @ISA = qw( System::Command );
 
 
@@ -30,7 +30,10 @@ for my $attr (qw( cmdline )) {
 # CAN I HAS GIT?
 my %binary;    # cache calls to _is_git
 sub _is_git {
-    my ($binary) = @_;
+    my ( $binary, @args ) = @_;
+
+    # git option might be an arrayref containing an executable with arguments
+    # Best that can be done is to check if the first part is executable
 
     # compute cache key:
     # - filename (path):     path
@@ -75,7 +78,8 @@ sub _is_git {
         if !( defined $git && -x $git );
 
     # try to run it
-    my ( $pid, $in, $out, $err ) = __PACKAGE__->spawn( $git, '--version' );
+    my ( $pid, $in, $out, $err )
+        = __PACKAGE__->spawn( $git, @args, '--version' );
     my $version = <$out>;
 
     # does it really look like git?
@@ -118,8 +122,12 @@ sub new {
 
     # get and check the git command
     my $git_cmd = ( map { exists $_->{git} ? $_->{git} : () } @o )[-1];
-    $git_cmd = 'git' if !defined $git_cmd;
-    my $git = _is_git($git_cmd);
+
+    # git option might be an arrayref containing an executable with arguments
+    # (e.g. [ qw( /usr/bin/sudo -u nobody git ) ] )
+    ( $git_cmd, my @args )
+        = defined $git_cmd ? ref $git_cmd ? @$git_cmd : ($git_cmd) : ('git');
+    my $git = _is_git($git_cmd, @args);
 
     croak "git binary '$git_cmd' not available or broken"
         if !defined $git;
@@ -128,7 +136,31 @@ sub new {
     delete $ENV{TERM};
 
     # spawn the command and re-bless the object in our class
-    return bless System::Command->new( $git, @cmd, @o ), $class;
+    return bless System::Command->new( $git, @args, @cmd, @o ), $class;
+}
+
+sub final_output {
+    my ($self) = @_;
+
+    # get output / errput
+    my ( $stdout, $stderr ) = @{$self}{qw(stdout stderr)};
+    chomp( my @output = <$stdout> );
+    chomp( my @errput = <$stderr> );
+
+    # done with it
+    $self->close;
+
+    # exit codes: 128 => fatal, 129 => usage
+    my $exit = $self->{exit};
+    if ( $exit == 128 || $exit == 129 ) {
+        croak join( "\n", @errput ) || 'fatal: unknown git error';
+    }
+
+    # something else's wrong
+    if (@errput) { carp join "\n", @errput; }
+
+    # return the output
+    return wantarray ? @output : join "\n", @output;
 }
 
 1;
@@ -200,6 +232,12 @@ I<option> hashes. The recognized keys are:
 
 The actual git binary to run. By default, it is just C<git>.
 
+In case the C<git> to be run is actually a command with parameters
+(e.g. when using B<sudo> or another command executer), the option value
+should be an array reference with the command and parameters, like this:
+
+    { git => [qw( sudo -u nobody git )] }
+
 =item C<cwd>
 
 The I<current working directory> in which the git command will be run.
@@ -241,6 +279,20 @@ number of attributes defined (see below).
 Close all pipes to the child process, and collects exit status, etc.
 and defines a number of attributes (see below).
 
+=head2 final_output()
+
+Collect all the output, and terminate the command.
+
+Returns the output as a string in scalar context,
+or as a list of lines in list context. Also accepts a hashref of options.
+
+Lines are automatically C<chomp>ed.
+
+If the Git command printed anything on stderr, it will be printed as
+warnings. If the git sub-process exited with status C<128> (fatal error),
+or C<129> (usage message), it will C<die()>.
+
+
 =head2 Accessors
 
 The attributes of a C<Git::Repository::Command> object are also accessible
